#
# spec file for package gnome-connections
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-connections
Version:        47.2.1
Release:        1.2
Summary:        A remote desktop client for GNOME
License:        GPL-3.0-or-later
URL:            https://wiki.gnome.org/Apps/Connections
Source:         %{name}-%{version}.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(freerdp3)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(gio-2.0) >= 2.50
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtk-vnc-2.0) > 0.4.4
BuildRequires:  pkgconfig(libhandy-1) >= 1.6.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.8
BuildRequires:  pkgconfig(winpr2) >= 2.0.0

%description
A remote desktop client for the GNOME desktop environment.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
# gtk-frdp is a subproject, do not offer it for consumption outside
rm -rf %{buildroot}%{_includedir}/%{name}/gtk-frdp/
rm %{buildroot}%{_libdir}/gnome-connections/pkgconfig/gtk-frdp-0.2.pc
rm %{buildroot}%{_datadir}/gnome-connections/gir-1.0/GtkFrdp-0.2.gir
rm %{buildroot}%{_datadir}/gnome-connections/vapi/gtk-frdp-0.2.deps
rm %{buildroot}%{_datadir}/gnome-connections/vapi/gtk-frdp-0.2.vapi

%check
%meson_test

%files
%license COPYING
%{_bindir}/gnome-connections
%dir %{_libdir}/gnome-connections
%dir %{_libdir}/gnome-connections/girepository-1.0
%{_libdir}/gnome-connections/girepository-1.0/GtkFrdp-0.2.typelib
%{_libdir}/gnome-connections/libgtk-frdp-0.2.so
%{_datadir}/metainfo/org.gnome.Connections.appdata.xml
%{_datadir}/applications/org.gnome.Connections.desktop
%{_datadir}/dbus-1/services/org.gnome.Connections.service
%{_datadir}/glib-2.0/schemas/org.gnome.Connections.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Connections.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Connections-symbolic.svg
%{_datadir}/mime/packages/org.gnome.Connections.xml

%files lang -f %{name}.lang

%changelog
* Tue Jan 28 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2.1:
  + Fix AppStream metadata
  + Fix key events in fullscreen mode
  + Fix scrolling for VNC connections
  + Start using GNOME Release Service
  + Add GIT_SUBMODULE_STRATEGY recursive to bundle subprojects
  + Switch to master gnome release service branch
  + Update gtk-frdp: Queue drawing of the area from the main thread
  + Updated translations.
* Sat Oct  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(freerdp2) with pkgconfig(freerdp3)
  BuildRequires: Move the newer, more up to date freerdp support.
* Fri Sep 13 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Updated translations.
- Changes from version 47.beta:
  + Update text describing remote desktop settings location
  + Make PATH translatable
  + Updated translations.
- Changes from version 47.alpha:
  + Bump freerdp version to 3.6.3 for flatpak
  + Fix build of flatpak
  + Move fullscreen button to the topbar
  + Fix handling of authentication/certificate dialog
  + Update gtk-frdp:
  - Make connection via RDP synchronous to prevent race
    conditions
  - Handle freerdp_shall_disconnect() sooner
  - Clear the update_id when the source is removed
  - Fix getting of properties for session
  - Do not block CPU during iterations
  - Disconnect handlers on disconnection
  - Wait until fuse-session thread is finished
  - Clear the clipboard if it contains remote data at finalize
  + Updated translations.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Update links in app metadata.
  + Clarify a title of a dialog.
  + Update gtk-frdp:
  - Do not attempt to process empty clipboard data.
  - Do not send coordinates with smooth scroll.
  - Limit value of mouse scroll.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Fixed touchpad scrolling.
  + Merge the duplicite doap files.
  + Add platform information to doap file.
  + Fix wrong developer id in metainfo.
  + Update gtk-frdp:
  - Add support for FreerRDP 3.
  - Handle smooth scroll events smoothly.
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Add certificate verification for RDP.
  + Add support for domains.
  + Improve text of onboarding.
  + Improve appdata for AppStream-1.0.
  + Fix translation of vala files.
  + Change icon for changed certificate.
  * Updated translations.
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Update gtk-frdp: Avoid files copy redundancy by using FUSE for
    pasting files
  - Update CI dependencies
  - Update flatpak modules
  + Updated translations.
- Add pkgconfig(fuse3) BuildRequires: New dependency.
* Sun Sep  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.rc:
  + Updated translations.
* Tue Aug  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Close onboarding dialog when pressing ESC.
  + Add mnemonics to Close/No Thanks button to onboarding.
  + Update gtk-frdp:
  - Desktop resize fixes.
  - Clipboard channel support.
  + Updated translations.
* Mon Apr 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Update gtk-frdp which fixes these 2 issues:
  - Wrong size after connection when resizing is enabled
  - Crash when connecting second time to the same machine
* Sat Mar 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Added rdp-preferences-window.vala to POTFILES.in.
  + Updated translations.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Update gtk-frdp.
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Update gtk-frdp
  + Allow resizing of remote desktops
  + Use app-id for icon name
  + Keep aspect ratios of remote desktops
  + Fix position of cursor for original scale
  + Switch to master branch of gtk-frdp
  + Use GNOME module post_install with meson
  + Updated translations.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Raise libhandy dependency to 1.6.0.
  + Update flatpak with gtk-vnc 1.3.1.
  + Update flatpak with freerdp 2.8 and disable FFMPEG.
  + Fix expanding of ConnectionsDisplayView on window resize.
  + Match appdata with app-id.
  + Update (or drop) the Docker image used by Flatpak job.
  + Wait for RDP connection to continue.
  + Updated translations.
* Wed Apr 13 2022 Emily Gonyer <emilyyrose@gmail.com>
- Changes from 42.1.1:
  + Fix handling of non-char keyboard input.
* Fri Apr  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1.1:
  + Fix crash with multiple simultaneous connections.
  + Allow for resizing and maximizing a display view.
  + Reset credentials when authentication fails.
  + Fix connection deletion on notification timeout.
- Changes from version 42.1:
  + Fixed double-free crash while connecting to RDP servers.
  + Fixed RDP scaling and resizing issues.
  + Updated translations.
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Add screenshots to appdata.
  + Updated translations.
* Wed Mar  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Finalize deleted connections
  + Save credentials in the keyring
  + Expose setting to enable/disable audio for VNC connections
  + Fix clibpard issues with VNC
  + Fix issue with the search grabing input from display
  + Added libhandy color scheme API
  + Improve thumbnail drawing logic
  + Updated translations.
- Add pkgconfig(libsecret-1) BuildRequires: New dependency.
- Add optional appstream-glib and desktop-file-utils BuildRequires:
  validate appstream and desktop file during build (meson_test).
* Tue Dec  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add check section and meson_test macro, run tests during build.
* Fri Dec  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + rdp-connection: Call show () when opening an already
    established connection
  + preferences: Remove activatable_widget property for the host
    address
  + build: Don't use internet for appstream validation test
  + vnc-connection: Only paste clipboard content that is text
  + Updated translations.
* Wed Oct 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Prevent search from stealing display key-press events.
  + Improve the parsing of incomplete addresses.
  + Draw RDP thumbnails on the app side.
  + Do not tap to clipboard until VNC connection is connected.
  + Fix missing app title in the Shell.
  + Add parameters to the Exec key in the desktop file.
  + Updated translations.
* Fri Sep 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + No changes.
* Thu Sep  2 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.rc:
  + Fix interactive authentication of RDP connections
  + Improve thumbnailer efficiency
- Changes from version 41.beta:
  + New onboarding dialog with instructions to use the app
  + Allow window to shrink
  + Connect to address after adding it
  + Validate server addresses
  + Display connection errors as notifications
  + Add command line option to launch a connection in fullscreen
  + Indicate that a connection is open by showing its thumbnail
  + Various internal refactorings
  + Updated translations.
- Changes from version 41.alpha:
  + Add shared clipboard support for VNC connections
  + Add a preferences dialog (based in Hdy.PreferencesWindow)
  + Introduce Onboarding dialog
  + Add new application icon
  + Add new connection creation assistant
  + Handle authentication failures
  + Add fullscreen support
  + Add VNC display scale modes setting
  + Default display scaling to "fit-window"
  + Add "vnc, rdp, remote" keywords to desktop file
  + Enable type-to-search in the main view
  + Only show search button when collection isn't empty
  + Dismiss notifications on exit
  + Add a few keyboard shortcuts
  + Update app metadata
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: New dependency.
* Tue Apr 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 40.0.1.
